======
pygcvs
======

.. image:: https://pypip.in/v/pygcvs/badge.png
    :target: https://crate.io/packages/pygcvs/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/pygcvs/badge.png
    :target: https://crate.io/packages/pygcvs/
    :alt: Number of PyPI downloads

.. image:: https://travis-ci.org/zsiciarz/pygcvs.png?branch=master
    :target: https://travis-ci.org/zsiciarz/pygcvs

A Python library for reading variable star data from the
`General Catalog of Variable Stars <http://www.sai.msu.su/gcvs/gcvs/iii/html/>`_.

Resources
---------

 * `Documentation <http://pygcvs.rtfd.org>`_
 * `Issue tracker <https://github.com/zsiciarz/pygcvs/issues>`_

Author
------

 * `Zbigniew Siciarz <http://siciarz.net>`_ (zbigniew at siciarz dot net)

License
-------

This work is released under the MIT license. A copy of the license is provided
in the LICENSE file.

